from _typeshed import Incomplete

error: str
CLSIDPyFile: str
RegistryIDPyFile: str
RegistryIDPycFile: str

def BuildDefaultPythonKey(): ...
def GetRootKey(): ...
def GetRegistryDefaultValue(subkey, rootkey: Incomplete | None = ...): ...
def SetRegistryDefaultValue(subKey, value, rootkey: Incomplete | None = ...) -> None: ...
def GetAppPathsKey(): ...
def RegisterPythonExe(exeFullPath, exeAlias: Incomplete | None = ..., exeAppPath: Incomplete | None = ...) -> None: ...
def GetRegisteredExe(exeAlias): ...
def UnregisterPythonExe(exeAlias) -> None: ...
def RegisterNamedPath(name, path) -> None: ...
def UnregisterNamedPath(name) -> None: ...
def GetRegisteredNamedPath(name): ...
def RegisterModule(modName, modPath) -> None: ...
def UnregisterModule(modName) -> None: ...
def GetRegisteredHelpFile(helpDesc): ...
def RegisterHelpFile(helpFile, helpPath, helpDesc: Incomplete | None = ..., bCheckFile: int = ...) -> None: ...
def UnregisterHelpFile(helpFile, helpDesc: Incomplete | None = ...) -> None: ...
def RegisterCoreDLL(coredllName: Incomplete | None = ...) -> None: ...
def RegisterFileExtensions(defPyIcon, defPycIcon, runCommand) -> None: ...
def RegisterShellCommand(shellCommand, exeCommand, shellUserCommand: Incomplete | None = ...) -> None: ...
def RegisterDDECommand(shellCommand, ddeApp, ddeTopic, ddeCommand) -> None: ...



from _typeshed import Incomplete
from typing import Any, Protocol, TypeVar, overload
from typing_extensions import TypeAlias

import _win32typing
from win32.lib.pywintypes import IIDType
from win32com.client import build as build

_T_co = TypeVar("_T_co", covariant=True)
_T = TypeVar("_T")

class _DispatchCreateClass(Protocol[_T_co]):
    @staticmethod
    def __call__(
        IDispatch: str | PyIDispatchType | _GoodDispatchTypes | PyIUnknownType,
        olerepr: build.DispatchItem | build.LazyDispatchItem,
        userName: str | None = ...,
        UnicodeToString: None = None,
        lazydata: Incomplete | None = ...,
    ) -> _T_co: ...

debugging: int
debugging_attr: int
LCID: int
ERRORS_BAD_CONTEXT: Incomplete
ALL_INVOKE_TYPES: Incomplete

def debug_print(*args) -> None: ...
def debug_attr_print(*args) -> None: ...
def MakeMethod(func, inst, cls): ...

PyIDispatchType = _win32typing.PyIDispatch
PyIUnknownType = _win32typing.PyIUnknown

_GoodDispatchTypes: TypeAlias = tuple[type[str], type[IIDType]]

@overload
def Dispatch(
    IDispatch: str | PyIDispatchType | _GoodDispatchTypes | PyIUnknownType,
    userName: str | None,
    createClass: _DispatchCreateClass[_T],
    typeinfo: _win32typing.PyITypeInfo | None = ...,
    UnicodeToString: None = None,
    clsctx: int = ...,
) -> _T: ...
@overload
def Dispatch(
    IDispatch: str | PyIDispatchType | _GoodDispatchTypes | PyIUnknownType,
    userName: str | None = ...,
    createClass: None = None,
    typeinfo: _win32typing.PyITypeInfo | None = ...,
    UnicodeToString: None = None,
    clsctx: int = ...,
) -> CDispatch: ...
def MakeOleRepr(IDispatch, typeinfo, typecomp): ...
def DumbDispatch(
    IDispatch,
    userName: Incomplete | None = ...,
    createClass: Incomplete | None = ...,
    UnicodeToString: Incomplete | None = ...,
    clsctx=...,
): ...

class CDispatch:
    def __init__(
        self,
        IDispatch,
        olerepr,
        userName: Incomplete | None = ...,
        UnicodeToString: None = None,
        lazydata: Incomplete | None = ...,
    ) -> None: ...
    def __call__(self, *args): ...
    def __bool__(self) -> bool: ...
    def __dir__(self): ...
    def __eq__(self, other): ...
    def __ne__(self, other): ...
    def __int__(self) -> int: ...
    def __len__(self) -> int: ...
    def __getitem__(self, index): ...
    def __setitem__(self, index, *args) -> None: ...
    def __LazyMap__(self, attr): ...
    def __AttrToID__(self, attr): ...
    ob: Incomplete
    # CDispatch objects are dynamically generated and too complex to type
    def __getattr__(self, attr: str) -> Any: ...
    def __setattr__(self, attr: str, value: Any) -> None: ...



from _typeshed import Incomplete, ReadableBuffer
from collections.abc import Callable, Iterable
from typing import TypedDict

import _win32typing
from win32.lib.pywintypes import error as error

class _MonitorInfo(TypedDict):
    Monitor: tuple[int, int, int, int]
    Work: tuple[int, int, int, int]
    Flags: int
    Device: str

class _FileVersionInfo(TypedDict):
    Signature: int
    StrucVersion: int
    FileVersionMS: int
    FileVersionLS: int
    ProductVersionMS: int
    ProductVersionLS: int
    FileFlagsMask: int
    FileFlags: int
    FileOS: int
    FileType: int
    FileSubtype: int
    FileDate: None | Incomplete

def AbortSystemShutdown(computerName: str) -> None: ...
def InitiateSystemShutdown(computerName: str, message: str, timeOut, bForceClose, bRebootAfterShutdown) -> None: ...
def Apply(exceptionHandler, func, args): ...
def Beep(freq, dur) -> None: ...
def BeginUpdateResource(filename: str, delete) -> int: ...
def ChangeDisplaySettings(DevMode: _win32typing.PyDEVMODE, Flags): ...
def ChangeDisplaySettingsEx(DeviceName: Incomplete | None = ..., DevMode: _win32typing.PyDEVMODE | None = ..., Flags=...): ...
def ClipCursor(arg: tuple[Incomplete, Incomplete, Incomplete, Incomplete]) -> None: ...
def CloseHandle(__handle: int) -> None: ...
def CopyFile(src, dest: str, bFailOnExist: int = ...) -> None: ...
def DebugBreak() -> None: ...
def DeleteFile(fileName: str) -> None: ...
def DragQueryFile(hDrop, fileNum: int = ...) -> str: ...
def DragFinish(hDrop) -> None: ...
def DuplicateHandle(
    __hSourceProcess: int,
    __hSource: int,
    __hTargetProcessHandle: int,
    __desiredAccess: int,
    __bInheritHandle: int,
    __options: int,
) -> int: ...
def EndUpdateResource(handle: int, discard) -> None: ...
def EnumDisplayDevices(Device: str | None = ..., DevNum: int = ..., Flags: int = ...) -> _win32typing.PyDISPLAY_DEVICE: ...
def EnumDisplayMonitors(
    hdc: int | None = ..., rcClip: _win32typing.PyRECT | None = ...
) -> list[tuple[_win32typing.PyHANDLE, _win32typing.PyHANDLE, tuple[int, int, int, int]]]: ...
def EnumDisplaySettings(DeviceName: str | None = ..., ModeNum: int = ...) -> _win32typing.PyDEVMODEW: ...
def EnumDisplaySettingsEx(ModeNum, DeviceName: str | None = ..., Flags=...) -> _win32typing.PyDEVMODEW: ...
def EnumResourceLanguages(
    hmodule: int, lpType: _win32typing.PyResourceId, lpName: _win32typing.PyResourceId
) -> list[Incomplete]: ...
def EnumResourceNames(hmodule: int, resType: _win32typing.PyResourceId) -> list[str]: ...
def EnumResourceTypes(hmodule: int) -> list[Incomplete]: ...
def ExpandEnvironmentStrings(_in: str) -> str: ...
def ExitWindows(reserved1: int = ..., reserved2: int = ...) -> None: ...
def ExitWindowsEx(flags, reserved: int = ...) -> None: ...
def FindFiles(fileSpec: str): ...
def FindFirstChangeNotification(pathName: str, bSubDirs, _filter): ...
def FindNextChangeNotification(handle: int) -> None: ...
def FindCloseChangeNotification(handle) -> None: ...
def FindExecutable(filename: str, _dir: str) -> tuple[Incomplete, str]: ...
def FormatMessage(
    __flags: int,
    __source: str | None = ...,
    __messageId: int = ...,
    __languageID: int = ...,
    __inserts: Iterable[str] | None = ...,
) -> str: ...
def FormatMessageW(
    __flags: int,
    __source: int | None = ...,
    __messageId: int = ...,
    __languageID: int = ...,
    __inserts: Iterable[str] | None = ...,
) -> str: ...
def FreeLibrary(hModule: int) -> None: ...
def GenerateConsoleCtrlEvent(__controlEvent: int, __processGroupId: int) -> None: ...
def GetAsyncKeyState(key): ...
def GetCommandLine() -> str: ...
def GetComputerName() -> str: ...
def GetComputerNameEx(NameType) -> str: ...
def GetComputerObjectName(NameFormat) -> str: ...
def GetMonitorInfo(hMonitor: int) -> _MonitorInfo: ...
def GetUserName() -> str: ...
def GetUserNameEx(__NameFormat: int) -> str: ...
def GetCursorPos() -> tuple[Incomplete, Incomplete]: ...
def GetCurrentThread(): ...
def GetCurrentThreadId(): ...
def GetCurrentProcessId(): ...
def GetCurrentProcess() -> int: ...
def GetConsoleTitle() -> str: ...
def GetDateFormat(locale, flags, time: _win32typing.PyTime, _format: str) -> str: ...
def GetDiskFreeSpace(rootPath: str): ...
def GetDiskFreeSpaceEx(__rootPath: str) -> tuple[int, int, int]: ...
def GetDllDirectory() -> str: ...
def GetDomainName() -> str: ...
def GetEnvironmentVariable(variable): ...
def GetEnvironmentVariableW(Name) -> str: ...
def GetFileAttributes(pathName: str): ...
def GetFileVersionInfo(__Filename: str, __SubBlock: str) -> _FileVersionInfo: ...
def GetFocus(): ...
def GetFullPathName(fileName: str) -> str: ...
def GetHandleInformation(__Object: int): ...
def GetKeyboardLayout(threadId: int = ...): ...
def GetKeyboardLayoutName(): ...
def GetKeyboardState() -> str: ...
def GetKeyState(key): ...
def GetLastError(): ...
def GetLastInputInfo(): ...
def GetLocalTime(): ...
def GetLongPathName(__fileName: str) -> str: ...
def GetLongPathNameW(fileName: str) -> str: ...
def GetLogicalDrives(): ...
def GetLogicalDriveStrings() -> str: ...
def GetModuleFileName(hModule: int) -> str: ...
def GetModuleFileNameW(hModule: int) -> str: ...
def GetModuleHandle(__fileName: str | None = ...) -> int: ...
def GetPwrCapabilities(): ...
def GetProfileSection(section: str, iniName: str | None = ...): ...
def GetProcAddress(hModule: int, functionName: _win32typing.PyResourceId): ...
def GetProfileVal(section: str, entry: str, defValue: str, iniName: str | None = ...) -> str: ...
def GetShortPathName(path: str) -> str: ...
def GetStdHandle(__handle: int) -> _win32typing.PyHANDLE: ...
def GetSysColor(index): ...
def GetSystemDefaultLangID(): ...
def GetSystemDefaultLCID(): ...
def GetSystemDirectory() -> str: ...
def GetSystemFileCacheSize(): ...
def SetSystemFileCacheSize(MinimumFileCacheSize, MaximumFileCacheSize, Flags=...) -> None: ...
def GetSystemInfo(): ...
def GetNativeSystemInfo(): ...
def GetSystemMetrics(__index: int) -> int: ...
def GetSystemPowerStatus() -> dict[str, int]: ...
def GetSystemTime(): ...
def GetTempFileName(path: str, prefix: str, nUnique): ...
def GetTempPath() -> str: ...
def GetThreadLocale(): ...
def GetTickCount() -> int: ...
def GetTimeFormat(locale, flags, time: _win32typing.PyTime, _format: str) -> str: ...
def GetTimeZoneInformation(times_as_tuples: bool = ...): ...
def GetVersion(): ...
def GetVersionEx(_format: int = ...): ...
def GetVolumeInformation(path: str): ...
def GetWindowsDirectory() -> str: ...
def GetWindowLong(__hwnd: int | None, __offset: int) -> int: ...
def GetUserDefaultLangID(): ...
def GetUserDefaultLCID(): ...
def GlobalMemoryStatus(): ...
def GlobalMemoryStatusEx() -> dict[str, int]: ...
def keybd_event(bVk, bScan, dwFlags: int = ..., dwExtraInfo: int = ...) -> None: ...
def mouse_event(dx, dy, dwData, dwFlags: int = ..., dwExtraInfo=...) -> None: ...
def LoadCursor(hInstance: int, cursorid: _win32typing.PyResourceId) -> int: ...
def LoadKeyboardLayout(KLID: str, Flags: int = ...): ...
def LoadLibrary(fileName: str): ...
def LoadLibraryEx(fileName: str, handle: int, handle1) -> int: ...
def LoadResource(handle: int, _type: _win32typing.PyResourceId, name: _win32typing.PyResourceId, language) -> str: ...
def LoadString(handle: int, stringId, numChars: int = ...) -> str: ...
def MessageBeep(arg): ...
def MessageBox(hwnd: int, message: str, title: str, arg, arg1): ...
def MonitorFromPoint(pt: tuple[Incomplete, Incomplete], Flags: int = ...) -> int: ...
def MonitorFromRect(__rc: _win32typing.PyRECT | tuple[int, int, int, int], __Flags: int = ...) -> int: ...
def MonitorFromWindow(hwnd: int, Flags: int = ...) -> int: ...
def MoveFile(srcName: str, destName: str) -> None: ...
def MoveFileEx(srcName: str, destName: str, flag) -> None: ...
def OpenProcess(__reqdAccess: int, __bInherit: int | bool, __pid: int) -> int: ...
def OutputDebugString(msg: str) -> None: ...
def PostMessage(hwnd: int, idMessage, wParam: Incomplete | None = ..., lParam: Incomplete | None = ...) -> None: ...
def PostQuitMessage(__exitCode: int = ...) -> None: ...
def PostThreadMessage(tid, idMessage, wParam: Incomplete | None = ..., lParam: Incomplete | None = ...) -> None: ...
def RegCloseKey(key: _win32typing.PyHKEY) -> None: ...
def RegConnectRegistry(computerName: str, key): ...
def RegCopyTree(KeySrc: _win32typing.PyHKEY, SubKey: str, KeyDest: _win32typing.PyHKEY) -> None: ...
def RegCreateKey(key: _win32typing.PyHKEY | int, subKey: str) -> _win32typing.PyHKEY: ...
def RegCreateKeyEx(
    Key: _win32typing.PyHKEY,
    SubKey: str,
    samDesired,
    Options,
    Class: str | None = ...,
    SecurityAttributes: _win32typing.PySECURITY_ATTRIBUTES | None = ...,
    Transaction: int | None = ...,
) -> tuple[_win32typing.PyHKEY, Incomplete]: ...
def RegDeleteKey(key: _win32typing.PyHKEY, subKey: str) -> None: ...
def RegDeleteKeyEx(Key: _win32typing.PyHKEY, SubKey: str, samDesired: int = ..., Transaction: int | None = ...) -> None: ...
def RegDeleteTree(Key: _win32typing.PyHKEY, SubKey: str) -> None: ...
def RegDeleteValue(key: _win32typing.PyHKEY, value: str) -> None: ...
def RegEnumKey(key: _win32typing.PyHKEY, index) -> str: ...
def RegEnumKeyEx(Key: _win32typing.PyHKEY): ...
def RegEnumKeyExW(Key: _win32typing.PyHKEY): ...
def RegEnumValue(key: _win32typing.PyHKEY, index) -> tuple[str, Incomplete, Incomplete]: ...
def RegFlushKey(key: _win32typing.PyHKEY) -> None: ...
def RegGetKeySecurity(key: _win32typing.PyHKEY, security_info) -> _win32typing.PySECURITY_DESCRIPTOR: ...
def RegLoadKey(key: _win32typing.PyHKEY, subKey: str, filename: str) -> None: ...
def RegOpenCurrentUser(samDesired) -> _win32typing.PyHKEY: ...
def RegOpenKey(
    __key: _win32typing.PyHKEY | int, __subkey: str | None, __reserved: bool = ..., __sam: int = ...
) -> _win32typing.PyHKEY: ...
def RegOpenKeyEx(__key: _win32typing.PyHKEY, __subKey: str, __sam: int, __reserved: bool = ...) -> _win32typing.PyHKEY: ...
def RegOpenKeyTransacted(
    Key: _win32typing.PyHKEY, SubKey: str, samDesired, Transaction: int, Options: int = ...
) -> _win32typing.PyHKEY: ...
def RegOverridePredefKey(Key: _win32typing.PyHKEY, NewKey: _win32typing.PyHKEY) -> None: ...
def RegQueryValue(key: _win32typing.PyHKEY, subKey: str) -> str: ...
def RegQueryValueEx(__key: _win32typing.PyHKEY | int, __valueName: str | None) -> tuple[str, int]: ...
def RegQueryInfoKey(key: _win32typing.PyHKEY) -> tuple[Incomplete, Incomplete, Incomplete]: ...
def RegQueryInfoKeyW(Key: _win32typing.PyHKEY): ...
def RegRestoreKey(Key: _win32typing.PyHKEY, File: str, Flags: int = ...) -> None: ...
def RegSaveKey(key: _win32typing.PyHKEY, filename: str, sa: _win32typing.PySECURITY_ATTRIBUTES | None = ...) -> None: ...
def RegSaveKeyEx(
    Key: _win32typing.PyHKEY, File: str, Flags, SecurityAttributes: _win32typing.PySECURITY_ATTRIBUTES | None = ...
) -> None: ...
def RegSetKeySecurity(key: _win32typing.PyHKEY, security_info, sd: _win32typing.PySECURITY_DESCRIPTOR) -> None: ...
def RegSetValue(key: _win32typing.PyHKEY, subKey: str | None, _type, value: str) -> None: ...
def RegSetValueEx(key: _win32typing.PyHKEY, valueName: str, reserved, _type, value) -> None: ...
def RegUnLoadKey(key: _win32typing.PyHKEY, subKey: str) -> None: ...
def RegisterWindowMessage(msgString: str) -> None: ...
def RegNotifyChangeKeyValue(key: _win32typing.PyHKEY, bWatchSubTree, dwNotifyFilter, hKey: int, fAsynchronous) -> None: ...
def SearchPath(path: str, fileName: str, fileExt: str | None = ...): ...
def SendMessage(hwnd: int, idMessage, wParam: str | None = ..., lParam: str | None = ...) -> None: ...
def SetConsoleCtrlHandler(__ctrlHandler: Callable[[int], bool], __bAdd: bool) -> None: ...
def SetConsoleTitle(title: str) -> None: ...
def SetCursorPos(arg: tuple[Incomplete, Incomplete]) -> None: ...
def SetDllDirectory(PathName: str) -> None: ...
def SetErrorMode(errorMode): ...
def SetFileAttributes(pathName: str, attrs): ...
def SetLastError(): ...
def SetSysColors(Elements, RgbValues) -> None: ...
def SetLocalTime(SystemTime: _win32typing.PyTime) -> None: ...
def SetSystemTime(year, month, dayOfWeek, day, hour, minute, second, millseconds): ...
def SetClassLong(hwnd: int, offset, val): ...
def SetClassWord(hwnd: int, offset, val): ...
def SetCursor(hCursor: int) -> int: ...
def SetEnvironmentVariable(Name, Value) -> None: ...
def SetEnvironmentVariableW(Name, Value) -> None: ...
def SetHandleInformation(Object: int, Mask, Flags) -> None: ...
def SetStdHandle(handle, handle1: int) -> None: ...
def SetSystemPowerState(Suspend, Force) -> None: ...
def SetThreadLocale(lcid) -> None: ...
def SetTimeZoneInformation(tzi): ...
def SetWindowLong(__hwnd: int | None, __offset: int, __value: float) -> int: ...
def ShellExecute(hwnd: int, op: str, file: str, params: str, _dir: str, bShow): ...
def ShowCursor(show): ...
def Sleep(time, bAlterable: int = ...): ...
def TerminateProcess(__handle: int, __exitCode: int) -> None: ...
def ToAsciiEx(vk, scancode, keyboardstate, flags: int = ..., hlayout: Incomplete | None = ...): ...
def Unicode() -> str: ...
def UpdateResource(
    __handle: int,
    __type: _win32typing.PyResourceId | int,
    __name: _win32typing.PyResourceId | int,
    __data: ReadableBuffer | None,
    language: int = ...,
) -> None: ...
def VkKeyScan(char, char1): ...
def WinExec(cmdLine: str, arg) -> None: ...
def WinHelp(hwnd: int, hlpFile: str, cmd, data: str | int = ...) -> None: ...
def WriteProfileSection(section: str, data: str, iniName: str | None = ...): ...
def WriteProfileVal(section: str, entry: str, value: str, iniName: str | None = ...) -> None: ...
def HIBYTE(__val: int) -> int: ...
def LOBYTE(__val: int) -> int: ...
def HIWORD(__val: int) -> int: ...
def LOWORD(__val: int) -> int: ...
def RGB(red, green, blue): ...
def MAKELANGID(PrimaryLanguage, SubLanguage): ...
def MAKEWORD(low, high): ...
def MAKELONG(low, high): ...
def CommandLineToArgv(*args, **kwargs): ...  # incomplete
def GetKeyboardLayoutList(*args, **kwargs): ...  # incomplete
def MapVirtualKey(*args, **kwargs): ...  # incomplete
def MessageBoxEx(*args, **kwargs): ...  # incomplete
def OpenThread(*args, **kwargs): ...  # incomplete
def SleepEx(*args, **kwargs): ...  # incomplete
def VkKeyScanEx(*args, **kwargs): ...  # incomplete

NameCanonical: int
NameCanonicalEx: int
NameDisplay: int
NameFullyQualifiedDN: int
NameSamCompatible: int
NameServicePrincipal: int
NameUniqueId: int
NameUnknown: int
NameUserPrincipal: int
PyDISPLAY_DEVICEType = _win32typing.PyDISPLAY_DEVICE
REG_NOTIFY_CHANGE_ATTRIBUTES: int
REG_NOTIFY_CHANGE_LAST_SET: int
REG_NOTIFY_CHANGE_NAME: int
REG_NOTIFY_CHANGE_SECURITY: int
STD_ERROR_HANDLE: int
STD_INPUT_HANDLE: int
STD_OUTPUT_HANDLE: int
VFT_APP: int
VFT_DLL: int
VFT_DRV: int
VFT_FONT: int
VFT_STATIC_LIB: int
VFT_UNKNOWN: int
VFT_VXD: int
VOS_DOS: int
VOS_DOS_WINDOWS16: int
VOS_DOS_WINDOWS32: int
VOS_NT: int
VOS_NT_WINDOWS32: int
VOS_OS216: int
VOS_OS216_PM16: int
VOS_OS232: int
VOS_OS232_PM32: int
VOS_UNKNOWN: int
VOS__PM16: int
VOS__PM32: int
VOS__WINDOWS16: int
VOS__WINDOWS32: int
VS_FF_DEBUG: int
VS_FF_INFOINFERRED: int
VS_FF_PATCHED: int
VS_FF_PRERELEASE: int
VS_FF_PRIVATEBUILD: int
VS_FF_SPECIALBUILD: int



from _typeshed import Incomplete
from typing import Literal
from typing_extensions import TypeAlias

import _win32typing

def odbc(connectionString: str) -> _win32typing.connection: ...
def SQLDataSources(direction) -> tuple[Incomplete, Incomplete]: ...

_odbcError: TypeAlias = type  # noqa: Y042  # Does not exist at runtime, but odbc.odbcError is a valid type.
DATE: str
NUMBER: str
RAW: str
SQL_FETCH_ABSOLUTE: int
SQL_FETCH_FIRST: int
SQL_FETCH_FIRST_SYSTEM: int
SQL_FETCH_FIRST_USER: int
SQL_FETCH_LAST: int
SQL_FETCH_NEXT: int
SQL_FETCH_PRIOR: int
SQL_FETCH_RELATIVE: int
STRING: str
TYPES: tuple[Literal["STRING"], Literal["RAW"], Literal["NUMBER"], Literal["DATE"]]
dataError: Incomplete
error: _odbcError
integrityError: Incomplete
internalError: Incomplete
noError: Incomplete
opError: Incomplete
progError: Incomplete



import _win32typing
from win32.lib.pywintypes import error as error

def CreateTransaction(
    TransactionAttributes: _win32typing.PySECURITY_ATTRIBUTES | None = ...,
    UOW: _win32typing.PyIID | None = ...,
    CreateOptions: int = ...,
    IsolationLevel: int = ...,
    IsolationFlags: int = ...,
    Timeout: int = ...,
    Description: str | None = ...,
) -> int: ...
def RollbackTransaction(TransactionHandle: int) -> None: ...
def RollbackTransactionAsync(TransactionHandle: int) -> None: ...
def CommitTransaction(TransactionHandle: int) -> None: ...
def CommitTransactionAsync(TransactionHandle: int) -> None: ...
def GetTransactionId(TransactionHandle: int) -> _win32typing.PyIID: ...
def OpenTransaction(DesiredAccess, TransactionId: _win32typing.PyIID) -> int: ...



from _typeshed import Incomplete
from typing import Literal

import _win32typing

def OpenPrinter(printer: str, Defaults: Incomplete | None = ...) -> _win32typing.PyPrinterHANDLE: ...
def GetPrinter(hPrinter: _win32typing.PyPrinterHANDLE, Level: int = ...): ...
def SetPrinter(hPrinter: _win32typing.PyPrinterHANDLE, Level, pPrinter, Command) -> None: ...
def ClosePrinter(hPrinter: _win32typing.PyPrinterHANDLE) -> None: ...
def AddPrinterConnection(printer: str): ...
def DeletePrinterConnection(printer: str): ...
def EnumPrinters(flags, name: str | None = ..., level: int = ...): ...
def GetDefaultPrinter() -> str: ...
def GetDefaultPrinterW() -> str: ...
def SetDefaultPrinter(printer: str): ...
def SetDefaultPrinterW(Printer: str): ...
def StartDocPrinter(
    __hprinter: _win32typing.PyPrinterHANDLE | int, __level: Literal[1], __tuple: tuple[str, str, str | None]
) -> int: ...
def EndDocPrinter(hPrinter: _win32typing.PyPrinterHANDLE): ...
def AbortPrinter(hPrinter: _win32typing.PyPrinterHANDLE) -> None: ...
def StartPagePrinter(hprinter: _win32typing.PyPrinterHANDLE) -> None: ...
def EndPagePrinter(hprinter: _win32typing.PyPrinterHANDLE) -> None: ...
def StartDoc(hdc: int, docinfo): ...
def EndDoc(hdc: int) -> None: ...
def AbortDoc(hdc: int) -> None: ...
def StartPage(hdc: int) -> None: ...
def EndPage(hdc: int) -> None: ...
def WritePrinter(__hprinter: int | _win32typing.PyPrinterHANDLE, __buf: bytes | bytearray | memoryview) -> int: ...
def EnumJobs(hPrinter: _win32typing.PyPrinterHANDLE, FirstJob, NoJobs, Level=...): ...
def GetJob(hPrinter: _win32typing.PyPrinterHANDLE, JobID, Level: int = ...): ...
def SetJob(hPrinter: _win32typing.PyPrinterHANDLE, JobID, Level, JobInfo, Command): ...
def DocumentProperties(
    HWnd: int,
    hPrinter: _win32typing.PyPrinterHANDLE,
    DeviceName: str,
    DevModeOutput: _win32typing.PyDEVMODE,
    DevModeInput: _win32typing.PyDEVMODE,
    Mode,
): ...
def EnumPrintProcessors(Server: str | None = ..., Environment: str | None = ...) -> tuple[str, ...]: ...
def EnumPrintProcessorDatatypes(ServerName: str, PrintProcessorName: str) -> tuple[str, ...]: ...
def EnumPrinterDrivers(Server: str | None = ..., Environment: str | None = ..., Level=...) -> tuple[Incomplete, ...]: ...
def EnumForms(hprinter: _win32typing.PyPrinterHANDLE) -> tuple[_win32typing.FORM_INFO_1, ...]: ...
def AddForm(hprinter: _win32typing.PyPrinterHANDLE, Form) -> None: ...
def DeleteForm(hprinter: _win32typing.PyPrinterHANDLE, FormName: str) -> None: ...
def GetForm(hprinter: _win32typing.PyPrinterHANDLE, FormName: str) -> None: ...
def SetForm(hprinter: _win32typing.PyPrinterHANDLE, FormName: str, Form) -> None: ...
def AddJob(hprinter: _win32typing.PyPrinterHANDLE) -> None: ...
def ScheduleJob(hprinter: _win32typing.PyPrinterHANDLE, JobId) -> None: ...
def DeviceCapabilities(Device: str, Port: str, Capability, DEVMODE: _win32typing.PyDEVMODE | None = ...) -> None: ...
def GetDeviceCaps(hdc: int, Index): ...
def EnumMonitors(Name: str, Level) -> tuple[Incomplete, ...]: ...
def EnumPorts(Name: str, Level) -> tuple[Incomplete, ...]: ...
def GetPrintProcessorDirectory(Name: str, Environment: str) -> str: ...
def GetPrinterDriverDirectory(Name: str, Environment: str) -> str: ...
def AddPrinter(Name: str, Level, pPrinter) -> _win32typing.PyPrinterHANDLE: ...
def DeletePrinter(hPrinter: _win32typing.PyPrinterHANDLE) -> None: ...
def DeletePrinterDriver(Server: str, Environment: str, DriverName: str) -> None: ...
def DeletePrinterDriverEx(Server: str, Environment: str, DriverName: str, DeleteFlag, VersionFlag) -> None: ...
def FlushPrinter(Printer: _win32typing.PyPrinterHANDLE, Buf, Sleep): ...

DEF_PRIORITY: int
DI_APPBANDING: int
DI_ROPS_READ_DESTINATION: int
DPD_DELETE_ALL_FILES: int
DPD_DELETE_SPECIFIC_VERSION: int
DPD_DELETE_UNUSED_FILES: int
DSPRINT_PENDING: int
DSPRINT_PUBLISH: int
DSPRINT_REPUBLISH: int
DSPRINT_UNPUBLISH: int
DSPRINT_UPDATE: int
FORM_BUILTIN: int
FORM_PRINTER: int
FORM_USER: int
JOB_ACCESS_ADMINISTER: int
JOB_ACCESS_READ: int
JOB_ALL_ACCESS: int
JOB_CONTROL_CANCEL: int
JOB_CONTROL_DELETE: int
JOB_CONTROL_LAST_PAGE_EJECTED: int
JOB_CONTROL_PAUSE: int
JOB_CONTROL_RESTART: int
JOB_CONTROL_RESUME: int
JOB_CONTROL_SENT_TO_PRINTER: int
JOB_EXECUTE: int
JOB_INFO_1: int
JOB_POSITION_UNSPECIFIED: int
JOB_READ: int
JOB_STATUS_BLOCKED_DEVQ: int
JOB_STATUS_COMPLETE: int
JOB_STATUS_DELETED: int
JOB_STATUS_DELETING: int
JOB_STATUS_ERROR: int
JOB_STATUS_OFFLINE: int
JOB_STATUS_PAPEROUT: int
JOB_STATUS_PAUSED: int
JOB_STATUS_PRINTED: int
JOB_STATUS_PRINTING: int
JOB_STATUS_RESTART: int
JOB_STATUS_SPOOLING: int
JOB_STATUS_USER_INTERVENTION: int
JOB_WRITE: int
MAX_PRIORITY: int
MIN_PRIORITY: int
PORT_STATUS_DOOR_OPEN: int
PORT_STATUS_NO_TONER: int
PORT_STATUS_OFFLINE: int
PORT_STATUS_OUTPUT_BIN_FULL: int
PORT_STATUS_OUT_OF_MEMORY: int
PORT_STATUS_PAPER_JAM: int
PORT_STATUS_PAPER_OUT: int
PORT_STATUS_PAPER_PROBLEM: int
PORT_STATUS_POWER_SAVE: int
PORT_STATUS_TONER_LOW: int
PORT_STATUS_TYPE_ERROR: int
PORT_STATUS_TYPE_INFO: int
PORT_STATUS_TYPE_WARNING: int
PORT_STATUS_USER_INTERVENTION: int
PORT_STATUS_WARMING_UP: int
PORT_TYPE_NET_ATTACHED: int
PORT_TYPE_READ: int
PORT_TYPE_REDIRECTED: int
PORT_TYPE_WRITE: int
PRINTER_ACCESS_ADMINISTER: int
PRINTER_ACCESS_USE: int
PRINTER_ALL_ACCESS: int
PRINTER_ATTRIBUTE_DEFAULT: int
PRINTER_ATTRIBUTE_DIRECT: int
PRINTER_ATTRIBUTE_DO_COMPLETE_FIRST: int
PRINTER_ATTRIBUTE_ENABLE_BIDI: int
PRINTER_ATTRIBUTE_ENABLE_DEVQ: int
PRINTER_ATTRIBUTE_FAX: int
PRINTER_ATTRIBUTE_HIDDEN: int
PRINTER_ATTRIBUTE_KEEPPRINTEDJOBS: int
PRINTER_ATTRIBUTE_LOCAL: int
PRINTER_ATTRIBUTE_NETWORK: int
PRINTER_ATTRIBUTE_PUBLISHED: int
PRINTER_ATTRIBUTE_QUEUED: int
PRINTER_ATTRIBUTE_RAW_ONLY: int
PRINTER_ATTRIBUTE_SHARED: int
PRINTER_ATTRIBUTE_TS: int
PRINTER_ATTRIBUTE_WORK_OFFLINE: int
PRINTER_CONTROL_PAUSE: int
PRINTER_CONTROL_PURGE: int
PRINTER_CONTROL_RESUME: int
PRINTER_CONTROL_SET_STATUS: int
PRINTER_ENUM_CONNECTIONS: int
PRINTER_ENUM_CONTAINER: int
PRINTER_ENUM_DEFAULT: int
PRINTER_ENUM_EXPAND: int
PRINTER_ENUM_ICON1: int
PRINTER_ENUM_ICON2: int
PRINTER_ENUM_ICON3: int
PRINTER_ENUM_ICON4: int
PRINTER_ENUM_ICON5: int
PRINTER_ENUM_ICON6: int
PRINTER_ENUM_ICON7: int
PRINTER_ENUM_ICON8: int
PRINTER_ENUM_LOCAL: int
PRINTER_ENUM_NAME: int
PRINTER_ENUM_NETWORK: int
PRINTER_ENUM_REMOTE: int
PRINTER_ENUM_SHARED: int
PRINTER_EXECUTE: int
PRINTER_INFO_1: int
PRINTER_READ: int
PRINTER_STATUS_BUSY: int
PRINTER_STATUS_DOOR_OPEN: int
PRINTER_STATUS_ERROR: int
PRINTER_STATUS_INITIALIZING: int
PRINTER_STATUS_IO_ACTIVE: int
PRINTER_STATUS_MANUAL_FEED: int
PRINTER_STATUS_NOT_AVAILABLE: int
PRINTER_STATUS_NO_TONER: int
PRINTER_STATUS_OFFLINE: int
PRINTER_STATUS_OUTPUT_BIN_FULL: int
PRINTER_STATUS_OUT_OF_MEMORY: int
PRINTER_STATUS_PAGE_PUNT: int
PRINTER_STATUS_PAPER_JAM: int
PRINTER_STATUS_PAPER_OUT: int
PRINTER_STATUS_PAPER_PROBLEM: int
PRINTER_STATUS_PAUSED: int
PRINTER_STATUS_PENDING_DELETION: int
PRINTER_STATUS_POWER_SAVE: int
PRINTER_STATUS_PRINTING: int
PRINTER_STATUS_PROCESSING: int
PRINTER_STATUS_SERVER_UNKNOWN: int
PRINTER_STATUS_TONER_LOW: int
PRINTER_STATUS_USER_INTERVENTION: int
PRINTER_STATUS_WAITING: int
PRINTER_STATUS_WARMING_UP: int
PRINTER_WRITE: int
SERVER_ACCESS_ADMINISTER: int
SERVER_ACCESS_ENUMERATE: int
SERVER_ALL_ACCESS: int
SERVER_EXECUTE: int
SERVER_READ: int
SERVER_WRITE: int



from _typeshed import Incomplete

import _win32typing
from win32.lib.pywintypes import error as error

def CreatePhonebookEntry(hWnd: int, fileName: str | None = ...) -> None: ...
def Dial(dialExtensions, fileName: str, RasDialParams: _win32typing.RASDIALPARAMS, callback) -> tuple[Incomplete, Incomplete]: ...
def EditPhonebookEntry(hWnd: int, fileName: str, entryName: str | None = ...) -> None: ...
def EnumConnections(): ...
def EnumEntries(reserved: str | None = ..., fileName: str | None = ...) -> None: ...
def GetConnectStatus(hrasconn) -> tuple[Incomplete, Incomplete, str, str]: ...
def GetEntryDialParams(
    fileName: str, entryName: str
) -> tuple[Incomplete, Incomplete, Incomplete, Incomplete, Incomplete, Incomplete, Incomplete]: ...
def GetErrorString(error) -> str: ...  # noqa: F811
def HangUp(hras) -> None: ...
def IsHandleValid(__hras: int | None) -> bool: ...
def SetEntryDialParams(fileName: str, RasDialParams, bSavePassword) -> None: ...
def RASDIALEXTENSIONS(*args, **kwargs): ...  # incomplete

RASCS_AllDevicesConnected: int
RASCS_AuthAck: int
RASCS_AuthCallback: int
RASCS_AuthChangePassword: int
RASCS_Authenticate: int
RASCS_Authenticated: int
RASCS_AuthLinkSpeed: int
RASCS_AuthNotify: int
RASCS_AuthProject: int
RASCS_AuthRetry: int
RASCS_CallbackComplete: int
RASCS_CallbackSetByCaller: int
RASCS_ConnectDevice: int
RASCS_Connected: int
RASCS_DeviceConnected: int
RASCS_Disconnected: int
RASCS_Interactive: int
RASCS_LogonNetwork: int
RASCS_OpenPort: int
RASCS_PasswordExpired: int
RASCS_PortOpened: int
RASCS_PrepareForCallback: int
RASCS_Projected: int
RASCS_ReAuthenticate: int
RASCS_RetryAuthentication: int
RASCS_StartAuthentication: int
RASCS_WaitForCallback: int
RASCS_WaitForModemReset: int

def GetEapUserIdentity(*args, **kwargs): ...  # incomplete

RASEAPF_Logon: int
RASEAPF_NonInteractive: int
RASEAPF_Preview: int



from _typeshed import Incomplete

import _win32typing

def CeRapiInit() -> None: ...
def CeRapiUninit() -> None: ...
def CreateProcess(
    __appName: str | None,
    __commandLine: str,
    __processAttributes: _win32typing.PySECURITY_ATTRIBUTES | None,
    __threadAttributes: _win32typing.PySECURITY_ATTRIBUTES | None,
    __bInheritHandles: int | bool,
    __dwCreationFlags: int,
    __newEnvironment: dict[str, str] | None,
    __currentDirectory: str | None,
    __startupinfo: _win32typing.PySTARTUPINFO,
) -> tuple[int, int, Incomplete, Incomplete]: ...
def CeRapiInitEx(): ...
def CeCopyFile(_from: str, to: str, bFailIfExists) -> None: ...
def CeCheckPassword(password: str) -> None: ...
def CeCreateFile(
    fileName: str,
    desiredAccess,
    shareMode,
    attributes: _win32typing.PySECURITY_ATTRIBUTES,
    creationDisposition,
    flagsAndAttributes,
    hTemplateFile: int,
) -> _win32typing.PyCEHANDLE: ...
def CeDeleteFile(fileName: str) -> None: ...
def CeMoveFile(existingFileName: str, newFileName: str) -> None: ...
def CeCreateDirectory(name: str, sa: _win32typing.PySECURITY_ATTRIBUTES) -> None: ...
def CeRemoveDirectory(lpPathName: str) -> None: ...
def CeGetTempPath() -> str: ...
def CeGetSystemInfo(): ...
def CeGetDesktopDeviceCaps(): ...
def CeGetSystemMetrics(): ...
def CeGetSpecialFolderPath() -> str: ...
def CeGetStoreInformation() -> tuple[Incomplete, Incomplete]: ...
def CeGetSystemPowerStatusEx(): ...
def CeSHCreateShortcut() -> None: ...
def CeSHGetShortcutTarget(): ...
def CeGetVersionEx() -> tuple[Incomplete, Incomplete, Incomplete, Incomplete, str]: ...
def CeGlobalMemoryStatus(): ...
def FindFiles(fileSpec: str): ...
def CeGetFileAttributes(fileName: str): ...
def CeSetFileAttributes(filename: str, newAttributes) -> None: ...
def CeGetFileSize(): ...
def CeReadFile(hFile: int, bufSize) -> str: ...
def WriteFile(__hFile: int, __data: str | bytes | _win32typing.PyOVERLAPPEDReadBuffer) -> tuple[int, int]: ...

CSIDL_BITBUCKET = ...
CSIDL_COMMON_DESKTOPDIRECTORY = ...
CSIDL_COMMON_PROGRAMS = ...
CSIDL_COMMON_STARTMENU = ...
CSIDL_COMMON_STARTUP = ...
CSIDL_CONTROLS = ...
CSIDL_DESKTOP = ...
CSIDL_DESKTOPDIRECTORY = ...
CSIDL_DRIVES = ...
CSIDL_FONTS = ...
CSIDL_NETHOOD = ...
CSIDL_NETWORK = ...
CSIDL_PERSONAL = ...
CSIDL_PRINTERS = ...
CSIDL_PROGRAMS = ...
CSIDL_RECENT = ...
CSIDL_SENDTO = ...
CSIDL_STARTMENU = ...
CSIDL_STARTUP = ...
CSIDL_TEMPLATES = ...



# Necessary for mypy to not fail with:
# 'error: Cannot find implementation or library stub for module named "win32comext.axscript.client.pyscript"'
# in: .gateways, .stackframe, .expressions, .adb, .contexts, .codecontainer, .documents, .debugger



from _typeshed import Incomplete

class OleItem:
    typename: str
    doc: Incomplete
    python_name: Incomplete
    bWritten: int
    bIsDispatch: int
    bIsSink: int
    clsid: Incomplete
    co_class: Incomplete
    def __init__(self, doc: Incomplete | None = ...) -> None: ...

class DispatchItem(OleItem):
    typename: str
    propMap: Incomplete
    propMapGet: Incomplete
    propMapPut: Incomplete
    mapFuncs: Incomplete
    defaultDispatchName: Incomplete
    hidden: int
    def __init__(
        self, typeinfo: Incomplete | None = ..., attr: Incomplete | None = ..., doc: Incomplete | None = ..., bForUser: int = ...
    ) -> None: ...
    clsid: Incomplete
    bIsDispatch: Incomplete
    def Build(self, typeinfo, attr, bForUser: int = ...) -> None: ...
    def CountInOutOptArgs(self, argTuple): ...
    def MakeFuncMethod(self, entry, name, bMakeClass: int = ...): ...
    def MakeDispatchFuncMethod(self, entry, name, bMakeClass: int = ...): ...
    def MakeVarArgsFuncMethod(self, entry, name, bMakeClass: int = ...): ...

class LazyDispatchItem(DispatchItem):
    typename: str
    clsid: Incomplete
    def __init__(self, attr, doc) -> None: ...



from setuptools import setup

name = "types-pywin32"
description = "Typing stubs for pywin32"
long_description = '''
## Typing stubs for pywin32

This is a [PEP 561](https://peps.python.org/pep-0561/)
type stub package for the [`pywin32`](https://github.com/mhammond/pywin32) package.
It can be used by type-checking tools like
[mypy](https://github.com/python/mypy/),
[pyright](https://github.com/microsoft/pyright),
[pytype](https://github.com/google/pytype/),
PyCharm, etc. to check code that uses
`pywin32`.

This version of `types-pywin32` aims to provide accurate annotations
for `pywin32==306.*`.
The source for this package can be found at
https://github.com/python/typeshed/tree/main/stubs/pywin32. All fixes for
types and metadata should be contributed there.

See https://github.com/python/typeshed/blob/main/README.md for more details.
This package was generated from typeshed commit `1de5830a2703936a96a126248227d5c7db883674` and was tested
with mypy 1.8.0, pyright 1.1.342, and
pytype 2023.12.18.
'''.lstrip()

setup(name=name,
      version="306.0.0.20240106",
      description=description,
      long_description=long_description,
      long_description_content_type="text/markdown",
      url="https://github.com/python/typeshed",
      project_urls={
          "GitHub": "https://github.com/python/typeshed",
          "Changes": "https://github.com/typeshed-internal/stub_uploader/blob/main/data/changelogs/pywin32.md",
          "Issue tracker": "https://github.com/python/typeshed/issues",
          "Chat": "https://gitter.im/python/typing",
      },
      install_requires=[],
      packages=['win32evtlog-stubs', 'win32netcon-stubs', 'isapi-stubs', 'win32inet-stubs', 'win32pdhquery-stubs', 'win32con-stubs', 'win32uiole-stubs', 'win32wnet-stubs', 'pywintypes-stubs', 'winxpgui-stubs', 'win32ts-stubs', 'win32gui-stubs', 'win32process-stubs', 'winioctlcon-stubs', 'winerror-stubs', 'perfmon-stubs', 'win32lz-stubs', 'win32help-stubs', 'win32crypt-stubs', 'pythonwin-stubs', 'win32print-stubs', 'win32-stubs', 'win32com-stubs', 'win32api-stubs', 'winxptheme-stubs', 'win32gui_struct-stubs', 'commctrl-stubs', 'win32service-stubs', 'win32transaction-stubs', 'mmapfile-stubs', 'win32net-stubs', 'servicemanager-stubs', 'win32ras-stubs', 'win32pipe-stubs', 'sspicon-stubs', 'win32file-stubs', 'mmsystem-stubs', 'winnt-stubs', 'timer-stubs', 'win32trace-stubs', 'win32clipboard-stubs', 'win32serviceutil-stubs', 'win32security-stubs', 'pythoncom-stubs', 'ntsecuritycon-stubs', 'win32console-stubs', 'winperf-stubs', 'win32pdh-stubs', 'win32job-stubs', 'dde-stubs', 'win32timezone-stubs', 'win32profile-stubs', 'regutil-stubs', '_win32typing-stubs', 'win32cryptcon-stubs', 'win32inetcon-stubs', 'win2kras-stubs', 'win32ui-stubs', 'win32comext-stubs', 'win32evtlogutil-stubs', 'win32cred-stubs', 'win32event-stubs', 'afxres-stubs', 'odbc-stubs'],
      package_data={'win32evtlog-stubs': ['__init__.pyi', 'METADATA.toml'], 'win32netcon-stubs': ['__init__.pyi', 'METADATA.toml'], 'isapi-stubs': ['__init__.pyi', 'isapicon.pyi', 'simple.pyi', 'threaded_extension.pyi', 'METADATA.toml'], 'win32inet-stubs': ['__init__.pyi', 'METADATA.toml'], 'win32pdhquery-stubs': ['__init__.pyi', 'METADATA.toml'], 'win32con-stubs': ['__init__.pyi', 'METADATA.toml'], 'win32uiole-stubs': ['__init__.pyi', 'METADATA.toml'], 'win32wnet-stubs': ['__init__.pyi', 'METADATA.toml'], 'pywintypes-stubs': ['__init__.pyi', 'METADATA.toml'], 'winxpgui-stubs': ['__init__.pyi', 'METADATA.toml'], 'win32ts-stubs': ['__init__.pyi', 'METADATA.toml'], 'win32gui-stubs': ['__init__.pyi', 'METADATA.toml'], 'win32process-stubs': ['__init__.pyi', 'METADATA.toml'], 'winioctlcon-stubs': ['__init__.pyi', 'METADATA.toml'], 'winerror-stubs': ['__init__.pyi', 'METADATA.toml'], 'perfmon-stubs': ['__init__.pyi', 'METADATA.toml'], 'win32lz-stubs': ['__init__.pyi', 'METADATA.toml'], 'win32help-stubs': ['__init__.pyi', 'METADATA.toml'], 'win32crypt-stubs': ['__init__.pyi', 'METADATA.toml'], 'pythonwin-stubs': ['__init__.pyi', 'dde.pyi', 'win32ui.pyi', 'win32uiole.pyi', 'METADATA.toml'], 'win32print-stubs': ['__init__.pyi', 'METADATA.toml'], 'win32-stubs': ['__init__.pyi', '_wincerapi.pyi', 'lib/__init__.pyi', 'lib/afxres.pyi', 'lib/commctrl.pyi', 'lib/mmsystem.pyi', 'lib/ntsecuritycon.pyi', 'lib/pywintypes.pyi', 'lib/regutil.pyi', 'lib/sspicon.pyi', 'lib/win2kras.pyi', 'lib/win32con.pyi', 'lib/win32cryptcon.pyi', 'lib/win32evtlogutil.pyi', 'lib/win32gui_struct.pyi', 'lib/win32inetcon.pyi', 'lib/win32netcon.pyi', 'lib/win32pdhquery.pyi', 'lib/win32serviceutil.pyi', 'lib/win32timezone.pyi', 'lib/winerror.pyi', 'lib/winioctlcon.pyi', 'lib/winnt.pyi', 'lib/winperf.pyi', 'lib/winxptheme.pyi', 'mmapfile.pyi', 'odbc.pyi', 'perfmon.pyi', 'servicemanager.pyi', 'timer.pyi', 'win32api.pyi', 'win32clipboard.pyi', 'win32console.pyi', 'win32cred.pyi', 'win32crypt.pyi', 'win32event.pyi', 'win32evtlog.pyi', 'win32file.pyi', 'win32gui.pyi', 'win32help.pyi', 'win32inet.pyi', 'win32job.pyi', 'win32lz.pyi', 'win32net.pyi', 'win32pdh.pyi', 'win32pipe.pyi', 'win32print.pyi', 'win32process.pyi', 'win32profile.pyi', 'win32ras.pyi', 'win32security.pyi', 'win32service.pyi', 'win32trace.pyi', 'win32transaction.pyi', 'win32ts.pyi', 'win32wnet.pyi', 'winxpgui.pyi', 'METADATA.toml'], 'win32com-stubs': ['__init__.pyi', 'adsi/__init__.pyi', 'adsi/adsi.pyi', 'adsi/adsicon.pyi', 'authorization/__init__.pyi', 'authorization/authorization.pyi', 'axcontrol/__init__.pyi', 'axcontrol/axcontrol.pyi', 'axdebug/__init__.pyi', 'axdebug/adb.pyi', 'axdebug/axdebug.pyi', 'axdebug/codecontainer.pyi', 'axdebug/contexts.pyi', 'axdebug/debugger.pyi', 'axdebug/documents.pyi', 'axdebug/expressions.pyi', 'axdebug/gateways.pyi', 'axdebug/stackframe.pyi', 'axdebug/util.pyi', 'axscript/__init__.pyi', 'axscript/asputil.pyi', 'axscript/axscript.pyi', 'axscript/client/__init__.pyi', 'axscript/client/error.pyi', 'axscript/server/__init__.pyi', 'axscript/server/axsite.pyi', 'axscript/server/error.pyi', 'bits/__init__.pyi', 'bits/bits.pyi', 'client/__init__.pyi', 'client/build.pyi', 'client/dynamic.pyi', 'client/gencache.pyi', 'directsound/__init__.pyi', 'directsound/directsound.pyi', 'ifilter/__init__.pyi', 'ifilter/ifilter.pyi', 'ifilter/ifiltercon.pyi', 'internet/__init__.pyi', 'internet/inetcon.pyi', 'internet/internet.pyi', 'mapi/__init__.pyi', 'mapi/_exchdapi.pyi', 'mapi/emsabtags.pyi', 'mapi/exchange.pyi', 'mapi/mapi.pyi', 'mapi/mapitags.pyi', 'mapi/mapiutil.pyi', 'olectl.pyi', 'propsys/__init__.pyi', 'propsys/propsys.pyi', 'propsys/pscon.pyi', 'server/__init__.pyi', 'server/connect.pyi', 'server/dispatcher.pyi', 'server/exception.pyi', 'server/policy.pyi', 'server/util.pyi', 'shell/__init__.pyi', 'shell/shell.pyi', 'shell/shellcon.pyi', 'storagecon.pyi', 'taskscheduler/__init__.pyi', 'taskscheduler/taskscheduler.pyi', 'universal.pyi', 'util.pyi', 'METADATA.toml'], 'win32api-stubs': ['__init__.pyi', 'METADATA.toml'], 'winxptheme-stubs': ['__init__.pyi', 'METADATA.toml'], 'win32gui_struct-stubs': ['__init__.pyi', 'METADATA.toml'], 'commctrl-stubs': ['__init__.pyi', 'METADATA.toml'], 'win32service-stubs': ['__init__.pyi', 'METADATA.toml'], 'win32transaction-stubs': ['__init__.pyi', 'METADATA.toml'], 'mmapfile-stubs': ['__init__.pyi', 'METADATA.toml'], 'win32net-stubs': ['__init__.pyi', 'METADATA.toml'], 'servicemanager-stubs': ['__init__.pyi', 'METADATA.toml'], 'win32ras-stubs': ['__init__.pyi', 'METADATA.toml'], 'win32pipe-stubs': ['__init__.pyi', 'METADATA.toml'], 'sspicon-stubs': ['__init__.pyi', 'METADATA.toml'], 'win32file-stubs': ['__init__.pyi', 'METADATA.toml'], 'mmsystem-stubs': ['__init__.pyi', 'METADATA.toml'], 'winnt-stubs': ['__init__.pyi', 'METADATA.toml'], 'timer-stubs': ['__init__.pyi', 'METADATA.toml'], 'win32trace-stubs': ['__init__.pyi', 'METADATA.toml'], 'win32clipboard-stubs': ['__init__.pyi', 'METADATA.toml'], 'win32serviceutil-stubs': ['__init__.pyi', 'METADATA.toml'], 'win32security-stubs': ['__init__.pyi', 'METADATA.toml'], 'pythoncom-stubs': ['__init__.pyi', 'METADATA.toml'], 'ntsecuritycon-stubs': ['__init__.pyi', 'METADATA.toml'], 'win32console-stubs': ['__init__.pyi', 'METADATA.toml'], 'winperf-stubs': ['__init__.pyi', 'METADATA.toml'], 'win32pdh-stubs': ['__init__.pyi', 'METADATA.toml'], 'win32job-stubs': ['__init__.pyi', 'METADATA.toml'], 'dde-stubs': ['__init__.pyi', 'METADATA.toml'], 'win32timezone-stubs': ['__init__.pyi', 'METADATA.toml'], 'win32profile-stubs': ['__init__.pyi', 'METADATA.toml'], 'regutil-stubs': ['__init__.pyi', 'METADATA.toml'], '_win32typing-stubs': ['__init__.pyi', 'METADATA.toml'], 'win32cryptcon-stubs': ['__init__.pyi', 'METADATA.toml'], 'win32inetcon-stubs': ['__init__.pyi', 'METADATA.toml'], 'win2kras-stubs': ['__init__.pyi', 'METADATA.toml'], 'win32ui-stubs': ['__init__.pyi', 'METADATA.toml'], 'win32comext-stubs': ['__init__.pyi', 'adsi/__init__.pyi', 'adsi/adsi.pyi', 'adsi/adsicon.pyi', 'authorization/__init__.pyi', 'authorization/authorization.pyi', 'axcontrol/__init__.pyi', 'axcontrol/axcontrol.pyi', 'axdebug/__init__.pyi', 'axdebug/adb.pyi', 'axdebug/axdebug.pyi', 'axdebug/codecontainer.pyi', 'axdebug/contexts.pyi', 'axdebug/debugger.pyi', 'axdebug/documents.pyi', 'axdebug/expressions.pyi', 'axdebug/gateways.pyi', 'axdebug/stackframe.pyi', 'axdebug/util.pyi', 'axscript/__init__.pyi', 'axscript/asputil.pyi', 'axscript/axscript.pyi', 'axscript/client/__init__.pyi', 'axscript/client/error.pyi', 'axscript/client/pyscript.pyi', 'axscript/server/__init__.pyi', 'axscript/server/axsite.pyi', 'axscript/server/error.pyi', 'bits/__init__.pyi', 'bits/bits.pyi', 'directsound/__init__.pyi', 'directsound/directsound.pyi', 'ifilter/__init__.pyi', 'ifilter/ifilter.pyi', 'ifilter/ifiltercon.pyi', 'internet/__init__.pyi', 'internet/inetcon.pyi', 'internet/internet.pyi', 'mapi/__init__.pyi', 'mapi/_exchdapi.pyi', 'mapi/emsabtags.pyi', 'mapi/exchange.pyi', 'mapi/mapi.pyi', 'mapi/mapitags.pyi', 'mapi/mapiutil.pyi', 'propsys/__init__.pyi', 'propsys/propsys.pyi', 'propsys/pscon.pyi', 'shell/__init__.pyi', 'shell/shell.pyi', 'shell/shellcon.pyi', 'taskscheduler/__init__.pyi', 'taskscheduler/taskscheduler.pyi', 'METADATA.toml'], 'win32evtlogutil-stubs': ['__init__.pyi', 'METADATA.toml'], 'win32cred-stubs': ['__init__.pyi', 'METADATA.toml'], 'win32event-stubs': ['__init__.pyi', 'METADATA.toml'], 'afxres-stubs': ['__init__.pyi', 'METADATA.toml'], 'odbc-stubs': ['__init__.pyi', 'METADATA.toml']},
      license="Apache-2.0 license",
      python_requires=">=3.8",
      classifiers=[
          "License :: OSI Approved :: Apache Software License",
          "Programming Language :: Python :: 3",
          "Typing :: Stubs Only",
      ]
)
